==> haskell-safe-exceptions-0.1.7.0-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe-exceptions
version: 0.1.7.0
id: safe-exceptions-0.1.7.0-IiYzP2iUv0fJkb2SM367bp
key: safe-exceptions-0.1.7.0-IiYzP2iUv0fJkb2SM367bp
license: MIT
copyright: 2016 FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/safe-exceptions#readme
synopsis: Safe, consistent, and easy exception handling
description:
    Please see README.md
category: Control
abi: af06fba0c38a2212bb15428c426fdcd4
exposed: True
exposed-modules:
    Control.Exception.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/safe-exceptions-0.1.7.0
hs-libraries: HSsafe-exceptions-0.1.7.0-IiYzP2iUv0fJkb2SM367bp
depends:
    base-4.11.1.0 deepseq-1.4.3.0
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock
haddock-html: /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safe-exceptions-0.1.7.0-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safe-exceptions
version: 0.1.7.0
id: safe-exceptions-0.1.7.0-JoI2dlAiSGnImg6t9fenWm
key: safe-exceptions-0.1.7.0-JoI2dlAiSGnImg6t9fenWm
license: MIT
copyright: 2016 FP Complete
maintainer: michael@fpcomplete.com
author: Michael Snoyman
homepage: https://github.com/fpco/safe-exceptions#readme
synopsis: Safe, consistent, and easy exception handling
description:
    Please see README.md
category: Control
abi: 52115917abb839308a70dd019e0e849a
exposed: True
exposed-modules:
    Control.Exception.Safe
import-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/safe-exceptions-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/safe-exceptions-0.1.7.0
hs-libraries: HSsafe-exceptions-0.1.7.0-JoI2dlAiSGnImg6t9fenWm
depends:
    base-4.11.1.0 deepseq-1.4.3.0
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO transformers-0.5.5.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock
haddock-html: /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
